@@ -52,6 +52,13 @@ namespace {
       return x;
    }
 
+   /// Calculate the size of the specified object.
+   template<typename T>
+   void
+   _proc(module::size_t &sz, const T &x) {
+      _serializer<T>::proc(sz, x);
+   }
+
    /// (De)serialize a scalar value.
    template<typename T>
    struct _serializer<T, typename std::enable_if<
@@ -65,11 +72,18 @@ namespace {
       proc(compat::istream &is, T &x) {
          is.read(reinterpret_cast<char *>(&x), sizeof(x));
       }
+
+      static void
+      proc(module::size_t &sz, const T &x) {
+         sz += sizeof(x);
+      }
    };
 
    /// (De)serialize a vector.
    template<typename T>
-   struct _serializer<compat::vector<T>> {
+   struct _serializer<compat::vector<T>,
+                      typename std::enable_if<
+                         !std::is_scalar<T>::value>::type> {
       static void
       proc(compat::ostream &os, const compat::vector<T> &v) {
          _proc<uint32_t>(os, v.size());
@@ -85,6 +99,38 @@ namespace {
          for (size_t i = 0; i < v.size(); i++)
             new(&v[i]) T(_proc<T>(is));
       }
+
+      static void
+      proc(module::size_t &sz, const compat::vector<T> &v) {
+         sz += sizeof(uint32_t);
+
+         for (size_t i = 0; i < v.size(); i++)
+            _proc<T>(sz, v[i]);
+      }
+   };
+
+   template<typename T>
+   struct _serializer<compat::vector<T>,
+                      typename std::enable_if<
+                         std::is_scalar<T>::value>::type> {
+      static void
+      proc(compat::ostream &os, const compat::vector<T> &v) {
+         _proc<uint32_t>(os, v.size());
+         os.write(reinterpret_cast<const char *>(v.begin()),
+                  v.size() * sizeof(T));
+      }
+
+      static void
+      proc(compat::istream &is, compat::vector<T> &v) {
+         v.reserve(_proc<uint32_t>(is));
+         is.read(reinterpret_cast<char *>(v.begin()),
+                 v.size() * sizeof(T));
+      }
+
+      static void
+      proc(module::size_t &sz, const compat::vector<T> &v) {
+         sz += sizeof(uint32_t) + sizeof(T) * v.size();
+      }
    };
 
    /// (De)serialize a module::section.
@@ -108,6 +154,9 @@ namespace {
       proc(S &s, QT &x) {
          _proc(s, x.type);
          _proc(s, x.size);
+         _proc(s, x.target_size);
+         _proc(s, x.target_align);
+         _proc(s, x.ext_type);
       }
    };
 
@@ -146,4 +195,11 @@ namespace clover {
    module::deserialize(compat::istream &is) {
       return _proc<module>(is);
    }
+
+   module::size_t
+   module::size() const {
+      size_t sz = 0;
+      _proc(sz, *this);
+      return sz;
+   }
 }
